kalabash-webmail
================

The Kalabash webmail Interface.

Installation
------------

Install this extension system-wide or inside a virtual environment by
running the following command::

  $ pip install kalabash-webmail
